%bcond_without check

# https://github.com/git-lfs/git-lfs
%global goipath         github.com/git-lfs/git-lfs/v3
Version:                3.2.0

%gometa

%global common_description %{expand:
Git extension for versioning large files.}

%global golicenses      LICENSE.md
%global godocs          docs CHANGELOG.md CODE-OF-CONDUCT.md\\\
                        CONTRIBUTING.md README.md

Name:		git-lfs
Release:	%mkrel 2
Summary:    Git extension for versioning large files
Group:		Development/Tools

License:        MIT
URL:            https://git-lfs.github.io/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source3:        README.Fedora

# Silence git warning about default branch.
Patch: https://github.com/git-lfs/git-lfs/commit/11fe8dc62ed2eb158eaec28af90d2f509e7fd91f.patch 
Patch1: 0002-CVE-2024-53263-reject-lf-in-creds.patch

BuildRequires:  golang(github.com/dpotapov/go-spnego)
BuildRequires:  golang(github.com/git-lfs/gitobj/v2) >= 2.1.0
BuildRequires:  golang(github.com/git-lfs/gitobj/v2/errors) >= 2.1.0
BuildRequires:  golang(github.com/git-lfs/go-netrc/netrc) >= 0-0.13.20220318gitf0c862d
BuildRequires:  golang(github.com/git-lfs/pktline)
BuildRequires:  golang(github.com/git-lfs/wildmatch/v2) >= 2.0.1
BuildRequires:  golang(github.com/leonelquinteros/gotext) >= 1.5.0
BuildRequires:  golang(github.com/mattn/go-isatty) >= 0.0.4
BuildRequires:  golang(github.com/olekukonko/ts)
BuildRequires:  golang(github.com/pkg/errors)
BuildRequires:  golang(github.com/rubyist/tracerx)
BuildRequires:  golang(github.com/spf13/cobra) >= 0.0.3
BuildRequires:  golang(github.com/ssgelm/cookiejarparser) >= 1.0.1
BuildRequires:  golang(golang.org/x/net/http2)
BuildRequires:  golang(golang.org/x/sync/semaphore)

# Generate man pages
BuildRequires:  ruby-ronn

%if %{with check}
# Tests
BuildRequires:  golang(github.com/stretchr/testify/assert) >= 1.6.1
BuildRequires:  golang(github.com/stretchr/testify/require) >= 1.6.1
BuildRequires:  golang(github.com/xeipuuv/gojsonschema)
BuildRequires:  perl-devel
BuildRequires:  perl-Test-Harness
# Tests require full git suite, but not generally needed.
BuildRequires:	git >= 1.8.5
%endif

Requires:	git >= 1.8.5

%description
Git Large File Storage (LFS) replaces large files such as audio samples,
videos, datasets, and graphics with text pointers inside Git, while
storing the file contents on a remote server.


%gopkg


%prep
%goprep
cp -p %SOURCE3 .
%autopatch -p1

# Modify tests so that they expect binaries where we build them.
sed -i -e 's!\.\./bin/!/%{gobuilddir}/bin/!g' t/Makefile
sed -i -e 's!^BINPATH=.\+!BINPATH="%{gobuilddir}/bin"!g' t/testenv.sh


%build
# Build manpages first (some embedding in the executable is done.)
pushd docs
ronn --roff man/*.ronn
%gobuild -o %{gobuilddir}/bin/mangen man/mangen.go
%{gobuilddir}/bin/mangen
popd

LDFLAGS="-X 'github.com/git-lfs/git-lfs/config.Vendor=Mageia %{mageia}' " \
%gobuild -o %{gobuilddir}/bin/git-lfs %{goipath}

# Build test executables
for cmd in t/cmd/*.go; do
    %gobuild -o "%{gobuilddir}/bin/$(basename $cmd .go)" "$cmd"
done
%gobuild -o "%{gobuilddir}/bin/git-lfs-test-server-api" t/git-lfs-test-server-api/*.go

# Move man pages out of docs so they don't get installed twice.
mv docs/man .


%install
%gopkginstall
install -Dpm0755 %{gobuilddir}/bin/git-lfs %{buildroot}%{_bindir}/%{name}
install -d -p %{buildroot}%{_mandir}/man1/
install -Dpm0644 man/*.1 %{buildroot}%{_mandir}/man1/
install -d -p %{buildroot}%{_mandir}/man5/
install -Dpm0644 man/*.5 %{buildroot}%{_mandir}/man5/


%post
if [ "x$(git config --type=bool --get 'fedora.git-lfs.no-modify-config')" != "xtrue" ]; then
%{_bindir}/%{name} install --system --skip-repo
fi

%preun
if [ $1 -eq 0 ] && \
   [ "x$(git config --type=bool --get 'fedora.git-lfs.no-modify-config')" != "xtrue" ]; then
    %{_bindir}/%{name} uninstall --system --skip-repo
fi
exit 0


%if %{with check}
%check
%gocheck
PATH=%{buildroot}%{_bindir}:%{gobuilddir}/bin:$PATH \
    make -C t PROVE_EXTRA_ARGS="-j$(getconf _NPROCESSORS_ONLN)"
%endif


%files
%doc README.md README.Fedora CHANGELOG.md docs
%doc LICENSE.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}*.5*

%gopkgfiles


%changelog
* Wed Jan 29 2025 ns80 <ns80> 3.2.0-2.mga10
+ Revision: 2143315
- add a patch from Debian for CVE-2024-53263 (mga#33931)

* Fri Oct 07 2022 guillomovitch <guillomovitch> 3.2.0-1.mga9
+ Revision: 1895360
- new version 3.2.0

* Sun Apr 03 2022 guillomovitch <guillomovitch> 3.1.2-1.mga9
+ Revision: 1842283
- new version 3.1.2

* Fri Mar 18 2022 umeabot <umeabot> 3.0.2-2.mga9
+ Revision: 1798843
- Mageia 9 Mass Rebuild

* Sun Jan 30 2022 guillomovitch <guillomovitch> 3.0.2-1.mga9
+ Revision: 1770672
- new version 3.0.2
- new version 2.13.2

* Tue Nov 10 2020 guillomovitch <guillomovitch> 2.12.1-1.mga8
+ Revision: 1644328
- new version 2.12.1

* Sat Sep 05 2020 guillomovitch <guillomovitch> 2.12.0-1.mga8
+ Revision: 1622264
- new version 2.12.0

* Tue May 12 2020 guillomovitch <guillomovitch> 2.11.0-1.mga8
+ Revision: 1583422
- new version 2.11.0

* Sat Mar 14 2020 guillomovitch <guillomovitch> 2.10.0-1.mga8
+ Revision: 1556387
- new version 2.10.0
+ bcornec <bcornec>
- Import git-mfs using fedora as a base
- Created package structure for git-lfs.

